'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var client = require('@apollo/client');
var fetch = require('cross-fetch');
var middleware = require('@vue-storefront/middleware');
var requestIp = require('request-ip');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var fetch__default = /*#__PURE__*/_interopDefaultLegacy(fetch);
var requestIp__default = /*#__PURE__*/_interopDefaultLegacy(requestIp);

const buildClient = (settings) => {
    // const errorLink = onError(({ graphQLErrors, networkError, operation }) => {
    //   if (graphQLErrors) {
    //     graphQLErrors.map((error) => logBuilder({label: '[GRAPHQL ERROR]', ...error, operation }));
    //   }
    //   if (networkError) {
    //     logBuilder({ label: '[NETWORK ERROR]', message: networkError });
    //   }
    // });
    const httpLink = client.createHttpLink({
        uri: settings.odooGraphqlUrl,
        credentials: 'include',
        fetch: fetch__default["default"],
        fetchOptions: settings.fetchOptions,
        headers: {
            Cookie: settings.sessionAuth,
            'resquest-host': settings.requestHost,
            'REAL-IP': settings.realIp
        }
    });
    const afterwareLink = new client.ApolloLink((operation, forward) => {
        return forward(operation).map((response) => {
            const context = operation.getContext();
            const authHeader = context.response.headers.get('set-cookie');
            if (response.data) {
                response.data.cookie = authHeader;
            }
            return response;
        });
    });
    const apolloLink = client.ApolloLink.from([
        //errorLink,
        afterwareLink.concat(httpLink)
    ]);
    return new client.ApolloClient({
        link: apolloLink,
        cache: new client.InMemoryCache(),
        ssrMode: true,
        credentials: 'include',
        defaultOptions: {
            query: {
                errorPolicy: "all",
                fetchPolicy: "no-cache",
            },
            mutate: {
                errorPolicy: "all",
            }
        }
    });
};

const sessionHeaderExtension = {
    name: 'sessionHeaderExtension ',
    hooks: (req, res) => {
        return {
            beforeCreate: ({ configuration }) => {
                const clientIp = requestIp__default["default"].getClientIp(req);
                return {
                    ...configuration,
                    sessionAuth: req.headers.cookie,
                    requestHost: req.headers.host,
                    realIp: clientIp
                };
            },
            beforeCall: ({ configuration, callName, args }) => args,
            afterCall: ({ configuration, callName, response }) => {
                if (response.data.cookie) {
                    res.setHeader('Set-cookie', response.data.cookie);
                }
                return response;
            }
        };
    }
};

var orderFragment = `
order {
  id
  name
  amountTotal
  amountTax    
  amountDelivery
  amountDiscounts
  dateOrder
  orderUrl
  stage
  coupons {
    code
    id
  }
  websiteOrderLine {
    id
    name
    product {
      id
      name
      image
      imageFilename
      displayName
      combinationInfo
    }
    quantity
    priceTotal
  }
  orderLines {
    id
    name
    product {
      id
      name
      image
      imageFilename
      displayName
      combinationInfo
      attributeValues {
        id,
        name,
        displayType,
        htmlColor        
      }
    }
    quantity
    priceTotal
  }
  partnerInvoice {
    id
    name
    street
    city
    phone
    zip
    country {
      id
    }
    state {
      id
    }
  }
  partnerShipping {
    id
    name
    street
    city
    phone
    zip
    country {
      id
    }
    state { 
      id
    }
  }
  shippingMethod{
    id
    name
    price
  }
}
`;

var productFragment = `
  id
  firstVariant{
    id
    combinationInfoVariant
    slug
    variantAttributeValues{
      id
      name
      attribute{
        id
        name
      }
    }
  }
  productVariants{
    id
    typeId
    visibility
    status
    name
    displayName
    sku
    barcode
    description
  }
  smallImage
  price
  name
  description
  image
  imageFilename
  combinationInfo
  slug
  sku
  jsonLd
  isInWishlist
  categories {
    id
    name
    slug
    parent{
      parent{
        id
      }
    }
  }
  attributeValues {
    id
    name
    displayType
    priceExtra
    attribute {
      id
      name
    }
    search
  }
`;

var wishlistItemsFragment = `
wishlistItems {
    id
    product {
      id
      name
      description
      image
      price
      imageFilename
      isInWishlist
      firstVariant{
        id
        combinationInfoVariant
      }
      slug
    }
  }
`;

var query$c = client.gql `
    query TemplateProduct($id: Int, $slug: String, $barcode: String) {
        product(id: $id, slug: $slug, barcode: $barcode) {
            ${productFragment}
        }
    }`;

const getProductTemplate = async (context, params, customQuery) => {
    const { getProductTemplate } = context.extendQuery(customQuery, { getProductTemplate: { query: query$c, variables: params }
    });
    const response = await context.client.query({
        variables: getProductTemplate.variables,
        query: getProductTemplate.query,
    });
    return response;
};

var query$b = client.gql `
    query TemplateProductList(
    $filter: ProductFilterInput
    $currentPage: Int
    $pageSize: Int = 5
    $search: String
    $sort: ProductSortInput
    ) {
    products(
        filter: $filter
        currentPage: $currentPage
        pageSize: $pageSize
        search: $search
        sort: $sort
    ) {
        totalCount
        attributeValues {
        id
        name
        displayType
        name
        htmlColor
        search
        attribute{
            id
            name
        }
        
        }
        products {
        ${productFragment}
        }
    }
}`;

const getProductTemplateList = async (context, params, customQuery) => {
    const { getProductTemplateList } = context.extendQuery(customQuery, { getProductTemplateList: { query: query$b, variables: params }
    });
    const response = await context.client.query({
        variables: getProductTemplateList.variables,
        query: getProductTemplateList.query
    });
    return response;
};

var query$a = client.gql `
query Category($slug: String, $id: Int) {
    category(slug: $slug, id: $id) {
        id
        name
        slug
        childs {
          id
          name
          slug
          childs {
            id
            name
            slug
          }
        }
      }
  }
`;

const getCategory = async (context, params, customQuery) => {
    const { getCategory } = context.extendQuery(customQuery, { getCategory: { query: query$a, variables: params } });
    const response = await context.client.query({
        variables: getCategory.variables,
        query: getCategory.query,
    });
    return response;
};

var query$9 = client.gql `
query CategoryList(
    $search: String
    $filter: CategoryFilterInput
    $currentPage: Int
    $pageSize: Int
    $sort: CategorySortInput
  ) {
    categories(
      search: $search
      filter: $filter
      currentPage: $currentPage
      pageSize: $pageSize
      sort: $sort
    ) {
      categories {
        id
        name
        slug
        childs {
          id
          name
          slug
          childs {
            id
            name
            slug
          }
        }
        parent {
          id
          name
          slug
          parent {
            id
            name
            slug
            childs {
              id
              name
              slug
              childs {
                id
                name
                slug
              }
            }
          }
        }
      }
    }
  }`;

const getCategoryList = async (context, params, customQuery) => {
    const { getCategoryList } = context.extendQuery(customQuery, { getCategoryList: { query: query$9, variables: params }
    });
    const response = await context.client.query({
        variables: getCategoryList.variables,
        query: getCategoryList.query
    });
    return response;
};

var query$8 = client.gql `
    query ProductVariant($productTemplateId: Int, $combinationId: [Int]) {
        productVariant( productTemplateId: $productTemplateId combinationId: $combinationId) {
            product {
                id
                image
                variantPrice
                variantPriceAfterDiscount
                variantHasDiscountedPrice
                alternativeProducts{
                    id
                    typeId
                    visibility
                    status
                    name
                    displayName
                    sku
                    barcode
                    description
                  }
            }
            productTemplateId
            displayName
            price
            listPrice
            hasDiscountedPrice
        }
    }`;

const getProductVariant = async (context, params, customQuery) => {
    const { getProductVariant } = context.extendQuery(customQuery, { getProductVariant: { query: query$8, variables: params }
    });
    const response = await context.client.query({
        variables: getProductVariant.variables,
        query: getProductVariant.query,
    });
    return response;
};

var query$7 = client.gql `
query Country($id: Int) {
  country (id: $id) {
    code,
    id,
    imageUrl,
    name,
    states{
      id
      name
      code
      }    
  }     
}
`;

const getCountry = async (context, params, customQuery) => {
    const { getCountry } = context.extendQuery(customQuery, { getCountry: { query: query$7, variables: params } });
    const response = await context.client.query({
        variables: getCountry.variables,
        query: getCountry.query,
    });
    return response;
};

var query$6 = client.gql `
query CountryList($filter: CountryFilterInput, $currentPage: Int, $pageSize: Int, $search: String, $sort: CountrySortInput) {
  countries(filter: $filter, currentPage: $currentPage, pageSize: $pageSize, search: $search, sort: $sort) {
    countries{
      code
      id
      imageUrl
      name
      states{
      id
      name
      code
      }
    }
  }
}
`;

const getCountryList = async (context, params, customQuery) => {
    const { getCountryList } = context.extendQuery(customQuery, { getCountryList: { query: query$6, variables: params }
    });
    const response = await context.client.query({
        variables: getCountryList.variables,
        query: getCountryList.query
    });
    return response;
};

var query$5 = client.gql `
  query MailingLists {
    mailingLists {
        mailingLists {
            id
            name
        }
    }
  }
`;

const getMailingLists = async (context, params, customQuery) => {
    const { getMailingLists } = context.extendQuery(customQuery, { getMailingLists: { query: query$5, variables: params }
    });
    const response = await context.client.query({
        variables: getMailingLists.variables,
        query: getMailingLists.query
    });
    return response;
};

var query$4 = client.gql `
query MailingContacts {
  mailingContacts {
    mailingContacts {
      id
      email
      companyName
      subscriptionList {   
        id
        mailingList {
          id
          name
        }
        optOut
      }
    }
  }
}
`;

const getMailingContacts = async (context, params, customQuery) => {
    const { getMailingContacts } = context.extendQuery(customQuery, { getMailingContacts: { query: query$4, variables: params }
    });
    const response = await context.client.query({
        variables: getMailingContacts.variables,
        query: getMailingContacts.query
    });
    return response;
};

var query$3 = client.gql `
query Orders{
  orders {
    orders {
      id
      name
      dateOrder
      stage
      amountUntaxed
      amountTax
      amountTotal
      amountDelivery
      partnerInvoice {  
        id
        name
        street
        city
        phone
        zip
        country {
          id
        }
        state {
          id
        }
      }
      partnerShipping {
        id
        name
        street
        city
        phone
        zip
        country {
          id
        }
        state {
          id
        }
      }
      orderLines {
        id
        name
        priceUnit
        quantity
        product {
          id
          name
          image
          image
          slug
          displayName
        }
      }
    }
  }
}
`;

const getOrders = async (context, params, customQuery) => {
    const { getOrders } = context.extendQuery(customQuery, { getOrders: { query: query$3, variables: params }
    });
    const response = await context.client.query({
        variables: getOrders.variables,
        query: getOrders.query
    });
    return response;
};

var mutation$7 = client.gql `
    mutation($productId: Int!, $quantity: Int!) {
        cartAddItem(productId: $productId, quantity: $quantity) {
            ${orderFragment}
        }
    }
`;

const cartAdd = async (context, params, customQuery) => {
    const { cartAdd } = context.extendQuery(customQuery, { cartAdd: { mutation: mutation$7, variables: params }
    });
    const response = await context.client.mutate({
        variables: cartAdd.variables,
        mutation: cartAdd.mutation,
    });
    return response;
};

var query$2 = client.gql `
  query {
    cart {
      ${orderFragment}
    }
  }
`;

const cartLoad = async (context, customQuery) => {
    const { cartLoad } = context.extendQuery(customQuery, { cartLoad: { query: query$2 } });
    const response = await context.client.query({
        query: cartLoad.query,
    });
    return response;
};

var mutation$6 = client.gql `
    mutation($lineId: Int!){
        cartRemoveItem(lineId: $lineId){
            ${orderFragment}
        }
    }
`;

const cartRemove = async (context, params, customQuery) => {
    const { cartRemove } = context.extendQuery(customQuery, { cartRemove: { mutation: mutation$6, variables: params }
    });
    const response = await context.client.mutate({
        variables: cartRemove.variables,
        mutation: cartRemove.mutation,
    });
    return response;
};

var mutation$5 = client.gql `
    mutation($lineId: Int!, $quantity: Int!) {
        cartUpdateItem(lineId: $lineId, quantity: $quantity) {
            ${orderFragment}
        }
    }
`;

const cartUpdate = async (context, params, customQuery) => {
    const { cartUpdate } = context.extendQuery(customQuery, { cartUpdate: { mutation: mutation$5, variables: params }
    });
    const response = await context.client.mutate({
        variables: cartUpdate.variables,
        mutation: cartUpdate.mutation,
    });
    return response;
};

var mutation$4 = client.gql `
  mutation($promo: String!){
    applyCoupon(promo: $promo){
      error
    }
  }`;

const cartApplyCoupon = async (context, params, customQuery) => {
    const { cartApplyCoupon } = context.extendQuery(customQuery, { cartApplyCoupon: { mutation: mutation$4, variables: params }
    });
    const response = await context.client.mutate({
        variables: cartApplyCoupon.variables,
        mutation: cartApplyCoupon.mutation,
    });
    return response;
};

var mutation$3 = client.gql `
    mutation($productId: Int!) {
        wishlistAddItem(productId: $productId) {
            ${wishlistItemsFragment} 
        }
    }
`;

const wishlistAdd = async (context, params, customQuery) => {
    const { wishlistAdd } = context.extendQuery(customQuery, { wishlistAdd: { mutation: mutation$3, variables: params }
    });
    const response = await context.client.mutate({
        variables: wishlistAdd.variables,
        mutation: wishlistAdd.mutation,
    });
    return response;
};

var query$1 = client.gql `
  query {
    wishlistItems {
      ${wishlistItemsFragment}
    }
  }
`;

const wishlistLoad = async (context, customQuery) => {
    const { wishlistLoad } = context.extendQuery(customQuery, { wishlistLoad: { query: query$1 } });
    const response = await context.client.query({
        query: wishlistLoad.query,
    });
    return response;
};

var mutation$2 = client.gql `
    mutation($wishId: Int!){
        wishlistRemoveItem(wishId: $wishId) {
            ${wishlistItemsFragment}
        }
    }  
`;

const wishlistRemove = async (context, params, customQuery) => {
    const { wishlistRemove } = context.extendQuery(customQuery, { wishlistRemove: { mutation: mutation$2, variables: params }
    });
    const response = await context.client.mutate({
        variables: wishlistRemove.variables,
        mutation: wishlistRemove.mutation,
    });
    return response;
};

var query = client.gql `
query Addresses($type: [AddressEnum]!) {
    addresses(filter: { addressType: $type }) {
    id
    name
    city
    street
    street2
    city
    state {
        id
        name
        code
    }
    zip
    email
    country {
        id
        name
        code
    }
    phone
    contacts {
        name
        phone
    }
}
}
`;

const getAddress = async (context, params, customQuery) => {
    const { getAddress } = context.extendQuery(customQuery, { getAddress: { query, variables: params } });
    const response = await context.client.query({
        variables: getAddress.variables,
        query: getAddress.query
    });
    return response;
};

var mutation$1 = client.gql `
mutation addAddress($address: AddAddressInput!, $type: AddressEnum!) {
    addAddress(type: $type, address: $address) {
      id
      name 
      street
      street2
      city
      zip
      state 
      {
        id
      }
      country
      {
        id
      }
      email
      phone
    }
  }`;

const addAddress = async (context, params, customQuery) => {
    const { addAddress } = context.extendQuery(customQuery, { addAddress: { mutation: mutation$1, variables: params }
    });
    const response = await context.client.mutate({
        variables: addAddress.variables,
        mutation: addAddress.mutation,
    });
    return response;
};

var mutation = client.gql `
mutation deleteAddress ($id: Int!) {
    deleteAddress(address: { id: $id }){
      result
    }
  }
`;

const deleteAddress = async (context, params, customQuery) => {
    const { deleteAddress } = context.extendQuery(customQuery, { deleteAddress: { mutation, variables: params }
    });
    const response = await context.client.mutate({
        variables: deleteAddress.variables,
        mutation: deleteAddress.mutation,
    });
    return response;
};

var apiEndpoints = /*#__PURE__*/Object.freeze({
  __proto__: null,
  getProductTemplate: getProductTemplate,
  getProductTemplateList: getProductTemplateList,
  getCategory: getCategory,
  getCategoryList: getCategoryList,
  getProductVariant: getProductVariant,
  getCountry: getCountry,
  getCountryList: getCountryList,
  getMailingLists: getMailingLists,
  getMailingContacts: getMailingContacts,
  getOrders: getOrders,
  cartAdd: cartAdd,
  cartLoad: cartLoad,
  cartRemove: cartRemove,
  cartUpdate: cartUpdate,
  cartApplyCoupon: cartApplyCoupon,
  wishlistAdd: wishlistAdd,
  wishlistLoad: wishlistLoad,
  wishlistRemove: wishlistRemove,
  getAddress: getAddress,
  addAddress: addAddress,
  deleteAddress: deleteAddress
});

const onCreate = (settings) => {
    const client = buildClient(settings);
    return {
        config: settings,
        client
    };
};
const { createApiClient } = middleware.apiClientFactory({
    onCreate,
    api: apiEndpoints,
    extensions: [
        sessionHeaderExtension
    ]
});

exports.createApiClient = createApiClient;
//# sourceMappingURL=index.js.map
